==> onos-yang-serializers-xml-2.0-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/YrtIetfTeTopologyOpParam.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317;

import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeNodeEvent;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of yrtIetfTeTopology.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class YrtIetfTeTopologyOpParam extends InnerModelObject implements YrtIetfTeTopology {
    protected TeNodeEvent teNodeEvent;

    @Override
    public TeNodeEvent teNodeEvent() {
        return teNodeEvent;
    }

    @Override
    public void teNodeEvent(TeNodeEvent teNodeEvent) {
        this.teNodeEvent = teNodeEvent;
    }

    @Override
    public int hashCode() {
        return Objects.hash(teNodeEvent);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof YrtIetfTeTopologyOpParam) {
            YrtIetfTeTopologyOpParam other = (YrtIetfTeTopologyOpParam) obj;
            return
                Objects.equals(teNodeEvent, other.teNodeEvent);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("teNodeEvent=" + teNodeEvent)
            .toString();
    }

    /**
     * Creates an instance of yrtIetfTeTopologyOpParam.
     */
    public YrtIetfTeTopologyOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}

==> onos-yang-serializers-xml-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/YrtIetfTeTopologyOpParam.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317;

import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeNodeEvent;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of yrtIetfTeTopology.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class YrtIetfTeTopologyOpParam extends InnerModelObject implements YrtIetfTeTopology {
    protected TeNodeEvent teNodeEvent;

    @Override
    public TeNodeEvent teNodeEvent() {
        return teNodeEvent;
    }

    @Override
    public void teNodeEvent(TeNodeEvent teNodeEvent) {
        this.teNodeEvent = teNodeEvent;
    }

    @Override
    public int hashCode() {
        return Objects.hash(teNodeEvent);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof YrtIetfTeTopologyOpParam) {
            YrtIetfTeTopologyOpParam other = (YrtIetfTeTopologyOpParam) obj;
            return
                Objects.deepEquals(teNodeEvent, other.teNodeEvent);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("teNodeEvent=" + teNodeEvent)
            .toString();
    }

    /**
     * Creates an instance of yrtIetfTeTopologyOpParam.
     */
    public YrtIetfTeTopologyOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}
